@@ -38,7 +38,6 @@
 /* We include stddef.h to get the system's definition of NULL
  */
 #include <stddef.h>
-#include <sys/param.h>
 
 /* Here we provide G_GNUC_EXTENSION as an alias for __extension__,
  * where this is valid. This allows for warningless compilation of
@@ -200,13 +199,11 @@
 #define	TRUE	(!FALSE)
 #endif
 
-#ifndef MAX
+#undef	MAX
 #define MAX(a, b)  (((a) > (b)) ? (a) : (b))
-#endif
 
-#ifndef MIN
+#undef	MIN
 #define MIN(a, b)  (((a) < (b)) ? (a) : (b))
-#endif
 
 #undef	ABS
 #define ABS(a)	   (((a) < 0) ? -(a) : (a))
